import type { EpochMillis } from "./EpochMillis";
import type { FileMetadata } from "./FileMetadata";
import type { FilePath } from "./FilePath";
import type { FileTagName } from "./FileTagName";
import type { MimeType } from "./MimeType";
import type { OriginalFileName } from "./OriginalFileName";
import type { RawFileUrl } from "./RawFileUrl";
import type { SizeInBytes } from "./SizeInBytes";
/**
 * Contains full information about a file, including its file metadata, file tags, original file name, and MIME type.
 */
export declare type FileDetails = {
    metadata: FileMetadata;
    mime: MimeType;
    originalFileName: OriginalFileName | null;
    tags: Array<FileTagName>;
    /**
     * The file's path.
     *
     * *We recommend you save this value to your database* (instead of the file's URL).
     *
     * This value always begins with a `/`.
     */
    filePath: FilePath;
    /**
     * The file's raw URL (i.e. with no file transformations applied).
     */
    fileUrl: RawFileUrl;
    /**
     * Time the file was uploaded or last overwritten. Epoch milliseconds (since midnight 1 January 1970, UTC).
     */
    lastModified: EpochMillis;
    /**
     * The size of the file in bytes.
     */
    size: SizeInBytes;
};
