import type { AccountId } from "../models/AccountId";
import type { ApiKeyDataValues } from "../models/ApiKeyDataValues";
import type { ApiKeyDetails } from "../models/ApiKeyDetails";
import type { ApiKeyId } from "../models/ApiKeyId";
import type { ApiKeyType } from "../models/ApiKeyType";
import type { DeleteApiKeyBatch } from "../models/DeleteApiKeyBatch";
export declare class ApiKeysService {
    /**
     * Creates a new public or secret API key for the account.
     * @param accountId
     * @param apiKeyType
     * @param requestBody
     * @returns ApiKeyDetails Success.
     * @throws ApiError
     */
    static createApiKey(accountId: AccountId, apiKeyType: ApiKeyType, requestBody: ApiKeyDataValues): Promise<ApiKeyDetails>;
    /**
     * Update an API key for an account.
     * @param accountId
     * @param apiKeyId
     * @param requestBody
     * @returns ApiKeyDetails Success.
     * @throws ApiError
     */
    static updateApiKey(accountId: AccountId, apiKeyId: ApiKeyId, requestBody: ApiKeyDataValues): Promise<ApiKeyDetails>;
    /**
     * Deletes an API key from an account.
     * @param accountId
     * @param apiKeyId
     * @returns any Success.
     * @throws ApiError
     */
    static deleteApiKey(accountId: AccountId, apiKeyId: ApiKeyId): Promise<any>;
    /**
     * Deletes multiple API keys from an account.
     * @param accountId
     * @param requestBody
     * @returns any Success.
     * @throws ApiError
     */
    static deleteApiKeyBatch(accountId: AccountId, requestBody: DeleteApiKeyBatch): Promise<any>;
}
