import type { AccountId } from "../models/AccountId";
import type { AccountJobId } from "../models/AccountJobId";
import type { AccountJobType } from "../models/AccountJobType";
import type { JobSummary } from "../models/JobSummary";
import type { ListRecentJobsResponse } from "../models/ListRecentJobsResponse";
export declare class JobsService {
    /**
     * Gets information on a job.
     *
     * This endpoint requires a `secret_*` API key.
     * @param accountId
     * @param jobType
     * @param jobId
     * @returns JobSummary Success.
     * @throws ApiError
     */
    static getJob(accountId: AccountId, jobType: AccountJobType, jobId: AccountJobId): Promise<JobSummary>;
    /**
     * Cancels an in-progress job.
     *
     * This endpoint requires a `secret_*` API key.
     * @param accountId
     * @param jobType
     * @param jobId
     * @returns void
     * @throws ApiError
     */
    static cancelJob(accountId: AccountId, jobType: AccountJobType, jobId: AccountJobId): Promise<void>;
    /**
     * Lists the most recently issued jobs.
     *
     * This endpoint requires a `secret_*` API key.
     * @param accountId
     * @param jobType
     * @returns ListRecentJobsResponse Success.
     * @throws ApiError
     */
    static listRecentJobs(accountId: AccountId, jobType: Array<AccountJobType>): Promise<ListRecentJobsResponse>;
}
