import type { AccountId } from "../models/AccountId";
import type { BeginMultipartUploadRequestV2 } from "../models/BeginMultipartUploadRequestV2";
import type { BeginMultipartUploadResponseV2 } from "../models/BeginMultipartUploadResponseV2";
import type { CompleteUploadPartRequest } from "../models/CompleteUploadPartRequest";
import type { UploadId } from "../models/UploadId";
import type { UploadPartIndex } from "../models/UploadPartIndex";
import type { UploadPartList } from "../models/UploadPartList";
import type { UploadPartV2 } from "../models/UploadPartV2";
export declare class UploadsService {
    /**
     * Begins a new multipart file upload process.
     *
     * See also: basic file uploads.
     * @param accountId
     * @param requestBody File upload parameters.
     * @returns BeginMultipartUploadResponseV2 Success.
     * @throws ApiError
     */
    static beginMultipartUpload(accountId: AccountId, requestBody: BeginMultipartUploadRequestV2): Promise<BeginMultipartUploadResponseV2>;
    /**
     * Marks an upload part as uploaded.
     *
     * You must call this endpoint after you have successfully issued a `PUT` request to the `uploadUrl` on the corresponding UploadPart.
     * @param accountId
     * @param uploadId
     * @param uploadPartIndex
     * @param requestBody
     * @returns void
     * @throws ApiError
     */
    static completeUploadPart(accountId: AccountId, uploadId: UploadId, uploadPartIndex: UploadPartIndex, requestBody: CompleteUploadPartRequest): Promise<void>;
    /**
     * Gets a remaining upload part for a multipart file upload.
     * @param accountId
     * @param uploadId
     * @param uploadPartIndex
     * @returns UploadPartV2 Success.
     * @throws ApiError
     */
    static getUploadPart(accountId: AccountId, uploadId: UploadId, uploadPartIndex: UploadPartIndex): Promise<UploadPartV2>;
    /**
     * Lists the remaining upload parts for a multipart file upload.
     *
     * An empty array is returned when the upload is complete.
     * @param accountId
     * @param uploadId
     * @returns UploadPartList Success.
     * @throws ApiError
     */
    static listUploadParts(accountId: AccountId, uploadId: UploadId): Promise<UploadPartList>;
}
