/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */

import type { FileMetadata } from "./FileMetadata";
import type { FilePathDefinition } from "./FilePathDefinition";
import type { FileTagName } from "./FileTagName";
import type { MimeType } from "./MimeType";
import type { UploadWidgetContainer } from "./UploadWidgetContainer";
import type { UploadWidgetEditor } from "./UploadWidgetEditor";
import type { UploadWidgetLayout } from "./UploadWidgetLayout";
import type { UploadWidgetLocale } from "./UploadWidgetLocale";
import type { UploadWidgetOnUpdate } from "./UploadWidgetOnUpdate";
import type { UploadWidgetStyles } from "./UploadWidgetStyles";

/**
 * The configuration object passed to the upload widget's `open()` method has this structure:
 */
export type UploadWidgetConfig = {
  container?: UploadWidgetContainer;
  editor?: UploadWidgetEditor;
  layout?: UploadWidgetLayout;
  locale?: UploadWidgetLocale;
  /**
   * Maximum number of files allowed.
   *
   * Default: infinity if multi=true
   */
  maxFileCount?: number;
  /**
   * Maximum file size allowed.
   *
   * Default: infinity
   */
  maxFileSizeBytes?: number;
  /**
   * An arbitrary JSON object to store against the uploaded file(s) as metadata.
   *
   * You can retrieve this later via a GetFileDetails request.
   */
  metadata?: FileMetadata;
  /**
   * File type filter.
   */
  mimeTypes?: Array<MimeType>;
  /**
   * Enables/disables multiple file uploads.
   *
   * Default: false
   */
  multi?: boolean;
  onUpdate?: UploadWidgetOnUpdate;
  /**
   * The path to upload the file(s) to.
   */
  path?: FilePathDefinition;
  /**
   * Shows/hides the 'finish' button, which is displayed after files are uploaded.
   *
   * If `showFinishButton = false`, `multi = false`, and `layout = "modal"`, then the modal will close immediately after the file is uploaded (instead of showing the file to the user).
   *
   * Default: true
   */
  showFinishButton?: boolean;
  /**
   * Shows/hides the 'remove' button, which is displayed next to each file after it's uploaded.
   *
   * Default: true
   */
  showRemoveButton?: boolean;
  styles?: UploadWidgetStyles;
  /**
   * The tags you specify here determine which rules will be executed for the upload(s).
   *
   * You create rules in the Upload Dashboard, and choose which tags trigger each rule.
   *
   * Rules include: max file size checks, traffic limit checks, rate limit checks, etc.
   */
  tags?: Array<FileTagName>;
};
