/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { AllowedOriginData } from "../models/AllowedOriginData";
import type { AllowedOriginWhitelistSettings } from "../models/AllowedOriginWhitelistSettings";
import { request as __request } from "../core/request";

export class AllowedOriginsService {
  /**
   * Adds an allowed origin to an account.
   * @param accountId
   * @param requestBody
   * @returns any Success.
   * @throws ApiError
   */
  public static async addAllowedOrigin(accountId: AccountId, requestBody: AllowedOriginData): Promise<any> {
    const result = await __request({
      method: "POST",
      path: `/v1/accounts/${accountId}/security/allowed_origins`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Removes an allowed origin from an account.
   * @param accountId
   * @param requestBody
   * @returns any Success.
   * @throws ApiError
   */
  public static async removeAllowedOrigin(accountId: AccountId, requestBody: AllowedOriginData): Promise<any> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/accounts/${accountId}/security/allowed_origins`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Updates the settings for an account's "allowed origin whitelist".
   * @param accountId
   * @param requestBody
   * @returns any Success.
   * @throws ApiError
   */
  public static async setAllowedOriginWhitelistSettings(
    accountId: AccountId,
    requestBody: AllowedOriginWhitelistSettings
  ): Promise<any> {
    const result = await __request({
      method: "PUT",
      path: `/v1/accounts/${accountId}/security/allowed_origins/settings`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }
}
