/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { EmailAddress } from "../models/EmailAddress";
import type { Invitation } from "../models/Invitation";
import type { SendInvitation } from "../models/SendInvitation";
import { request as __request } from "../core/request";

export class InvitationsService {
  /**
   * Sends an account invitation to an email address.
   * @param accountId
   * @param requestBody
   * @returns Invitation Success.
   * @throws ApiError
   */
  public static async sendInvitation(accountId: AccountId, requestBody: SendInvitation): Promise<Invitation> {
    const result = await __request({
      method: "POST",
      path: `/v1/accounts/${accountId}/invitations`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Accepts an account invitation.
   * @param accountId
   * @returns any Success.
   * @throws ApiError
   */
  public static async acceptInvitation(accountId: AccountId): Promise<any> {
    const result = await __request({
      method: "PUT",
      path: `/v1/accounts/${accountId}/invitations/accept_mine`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Revokes an account invitation to an email address.
   * @param accountId
   * @param email
   * @returns any Success.
   * @throws ApiError
   */
  public static async revokeInvitation(accountId: AccountId, email: EmailAddress): Promise<any> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/accounts/${accountId}/invitations/${email}`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }
}
