/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { NpmPackageName } from "../models/NpmPackageName";
import type { Plugin } from "../models/Plugin";
import type { SemanticVersion } from "../models/SemanticVersion";
import { request as __request } from "../core/request";

export class PluginsService {
  /**
   * Installs a custom plugin to an account.
   * @param accountId
   * @param packageName
   * @param packageVersion
   * @returns Plugin Success.
   * @throws ApiError
   */
  public static async installCustomPlugin(
    accountId: AccountId,
    packageName: NpmPackageName,
    packageVersion: SemanticVersion
  ): Promise<Plugin> {
    const result = await __request({
      method: "PUT",
      path: `/v1/accounts/${accountId}/plugins/${packageName}/${packageVersion}`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Uninstalls a custom plugin from an account.
   * @param accountId
   * @param packageName
   * @param packageVersion
   * @returns any Success.
   * @throws ApiError
   */
  public static async uninstallCustomPlugin(
    accountId: AccountId,
    packageName: NpmPackageName,
    packageVersion: SemanticVersion
  ): Promise<any> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/accounts/${accountId}/plugins/${packageName}/${packageVersion}`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }
}
